@@ -12,11 +12,15 @@ public:
 	int remove(char *string);
 	int lookup(char *string);
 
+
 	char *reverse(int pos);
+	void sub_ref(int pos);
 
 private:
 	struct hash_struct
 	{
+		unsigned int refcount;
+
 		int pos;
 		char *string;
 
